/* /////////////////////////////////////////////////////////////////////////////
//
//                  RC MODULE PROPRIETARY INFORMATION
//     This software is supplied under the terms of a license agreement or
//     nondisclosure agreement with RC MODULE and may not be copied
//     or disclosed except in accordance with the terms of that agreement.
//          Copyright (c) 2006 RC MODULE. All Rights Reserved.
//
//              Traffic Monitor(R) Kernel
//                    
////////////////////////////////////////////////////////////////////////////////
*/

#ifndef _TMKERNEL_H_
#define _TMKERNEL_H_

#ifdef _WIN32
  #define __TMKER_STDCALL	__stdcall
#else
  #define __TMKER_STDCALL
#endif

typedef enum tagTMKER_RESULT
{
	TMKER_RES_OK,
	TMKER_RES_INVALID_FUNC_PARAMETER,
	TMKER_RES_MEMORY_ALLOC,
	TMKER_RES_INVALID_AFFIXMENT,
	TMKER_RES_DONGLE,
	TMKER_RES_NO_INIT
} TMKER_RESULT;

typedef enum tagTMKER_VEHICLE_CLASS
{
	TMKER_VC_MOTORCYCLE,
	TMKER_VC_CAR,
	TMKER_VC_STRUCK,
	TMKER_VC_BUS,
	TMKER_VC_MTRUCK,
	TMKER_VC_LTRUCK
} TMKER_VEHICLE_CLASS;

#define TMKER_MAX_VCLASSES TMKER_VC_LTRUCK + 1
#define TMKER_MAX_LANES 6

typedef struct tagS_TMKER_LaneEvent
{
	int nVehicleSpeed;
	int nVehicleLength;
	int nVehicleHeadway;
	int nVehicleOnScreenX;
	int nVehicleOnScreenY;
	TMKER_VEHICLE_CLASS nVehicleClass;
	int nIsVehicleInDetectionArea;
} S_TMKER_LaneEvent;

typedef struct tagS_TMKER_Event
{
	S_TMKER_LaneEvent Events[TMKER_MAX_LANES];
} S_TMKER_Event;

typedef struct tagS_TMKER_Point
{
	short shX;
	short shY;
} S_TMKER_Point;

typedef struct tagS_TMKER_Affixment
{
	int nLanes;
	int nDirection[TMKER_MAX_LANES];
	int nLanesWidth[TMKER_MAX_LANES];
	S_TMKER_Point pptImage[4];
	S_TMKER_Point pptEarth[4];
	S_TMKER_Point pptLeftRoadEdge[2];
	S_TMKER_Point pptRightRoadEdge[2];
} S_TMKER_Affixment;

typedef struct tagS_TMKER_Init
{
	int nFrameWidth;
	int nFrameHeight;
	int nFrameRate;
	S_TMKER_Affixment Affix;
} S_TMKER_Init;

typedef int TMKER_DESC;

#ifdef __cplusplus
extern "C" {
#endif

	TMKER_RESULT	__TMKER_STDCALL TMKER_GetLibVersion( int *pLibVersionMajor, int *pLibVersionMinor );
	TMKER_RESULT	__TMKER_STDCALL TMKER_Create( TMKER_DESC *pTMKernel );
	void			__TMKER_STDCALL TMKER_Destroy( TMKER_DESC TMKernel );
	TMKER_RESULT	__TMKER_STDCALL TMKER_Init( TMKER_DESC TMKernel, const S_TMKER_Init *pInit );
	void			__TMKER_STDCALL TMKER_Release( TMKER_DESC TMKernel );
	TMKER_RESULT	__TMKER_STDCALL TMKER_ProcessFrame( TMKER_DESC TMKernel, const unsigned char *pData, S_TMKER_Event *pEvent );
	TMKER_RESULT	__TMKER_STDCALL TMKER_ScreenToPrj( TMKER_DESC TMKernel, const S_TMKER_Point *pptScreen, S_TMKER_Point *pptPrj );
	TMKER_RESULT	__TMKER_STDCALL TMKER_PrjToScreen( TMKER_DESC TMKernel, const S_TMKER_Point *pptPrj, S_TMKER_Point *pptScreen );
	TMKER_RESULT	__TMKER_STDCALL TMKER_GetDongleLimit(unsigned int *punDongleLimit);

#ifdef __cplusplus
}
#endif

#endif
